@@ -60,7 +60,8 @@ RSA *rsa = NULL;
 int32_t my_select(int32_t fd, fd_set *fdread, fd_set *fdwrite, fd_set *fdex, long sec, long usec);
 
 /* ----------------- alarming functions ---------------- */
-void alarming() {
+void alarming(int signal) {
+  (signal);
   fail++;
   alarm_went_off++;
 
@@ -664,7 +665,7 @@ char *hydra_get_next_pair() {
     // if (debug) hydra_dump_data(pair, __fck, "CHILD READ PAIR");
     if (pair[0] == 0 || __fck <= 0)
       return HYDRA_EMPTY;
-    if (__fck >=  sizeof(HYDRA_EXIT) && memcmp(&HYDRA_EXIT, &pair, sizeof(HYDRA_EXIT)) == 0)
+    if (__fck >= sizeof(HYDRA_EXIT) && memcmp(&HYDRA_EXIT, &pair, sizeof(HYDRA_EXIT)) == 0)
       return HYDRA_EXIT;
   }
   return pair;
