@@ -25,7 +25,7 @@ char *nntp_read_server_capacity(int32_t sock) {
       free(buf);
     ptr = buf = hydra_receive_line(sock);
     if (buf != NULL) {
-      if (isdigit((int32_t) buf[0]) && buf[3] == ' ')
+      if (isdigit((int32_t)buf[0]) && buf[3] == ' ')
         resp = 1;
       else {
         if (buf[strlen(buf) - 1] == '\n')
@@ -38,7 +38,7 @@ char *nntp_read_server_capacity(int32_t sock) {
         if ((ptr = strrchr(buf, '\n')) != NULL) {
 #endif
           ptr++;
-          if (isdigit((int32_t) *ptr) && *(ptr + 3) == ' ')
+          if (isdigit((int32_t)*ptr) && *(ptr + 3) == ' ')
             resp = 1;
         }
       }
@@ -47,8 +47,8 @@ char *nntp_read_server_capacity(int32_t sock) {
   return buf;
 }
 
-int32_t start_nntp(int32_t s, char *ip, int32_t port, unsigned char options, char *miscptr, FILE * fp) {
-  char *empty = "\"\"";
+int32_t start_nntp(int32_t s, char *ip, int32_t port, unsigned char options, char *miscptr, FILE *fp) {
+  char *empty = "\"\"", *result = NULL;
   char *login, *pass, buffer[500], buffer2[500], *fooptr;
   int32_t i = 1;
 
@@ -79,7 +79,7 @@ int32_t start_nntp(int32_t s, char *ip, int32_t port, unsigned char options, cha
     }
     free(buf);
     strcpy(buffer2, login);
-    hydra_tobase64((unsigned char *) buffer2, strlen(buffer2), sizeof(buffer2));
+    hydra_tobase64((unsigned char *)buffer2, strlen(buffer2), sizeof(buffer2));
 
     sprintf(buffer, "%.250s\r\n", buffer2);
     if (hydra_send(s, buffer, strlen(buffer), 0) < 0) {
@@ -94,7 +94,7 @@ int32_t start_nntp(int32_t s, char *ip, int32_t port, unsigned char options, cha
     }
     free(buf);
     strcpy(buffer2, pass);
-    hydra_tobase64((unsigned char *) buffer2, strlen(buffer2), sizeof(buffer2));
+    hydra_tobase64((unsigned char *)buffer2, strlen(buffer2), sizeof(buffer2));
     sprintf(buffer, "%.250s\r\n", buffer2);
     break;
   case AUTH_PLAIN:
@@ -112,7 +112,9 @@ int32_t start_nntp(int32_t s, char *ip, int32_t port, unsigned char options, cha
     free(buf);
 
     memset(buffer, 0, sizeof(buffer));
-    sasl_plain(buffer, login, pass);
+    result = sasl_plain(buffer, login, pass);
+    if (result == NULL)
+      return 3;
 
     char tmp_buffer[sizeof(buffer)];
     sprintf(tmp_buffer, "%.250s\r\n", buffer);
@@ -120,128 +122,125 @@ int32_t start_nntp(int32_t s, char *ip, int32_t port, unsigned char options, cha
 
     break;
 #ifdef LIBOPENSSL
-  case AUTH_CRAMMD5:{
-      int32_t rc = 0;
-      char *preplogin;
+  case AUTH_CRAMMD5: {
+    int32_t rc = 0;
+    char *preplogin;
 
-      rc = sasl_saslprep(login, SASL_ALLOW_UNASSIGNED, &preplogin);
-      if (rc) {
-        return 3;
-      }
-
-      sprintf(buffer, "AUTHINFO SASL CRAM-MD5\r\n");
-      if (hydra_send(s, buffer, strlen(buffer), 0) < 0) {
-        return 1;
-      }
-      //get the one-time BASE64 encoded challenge
-      if ((buf = hydra_receive_line(s)) == NULL)
-        return 1;
-      if (buf == NULL || strstr(buf, "383") == NULL) {
-        hydra_report(stderr, "[ERROR] NNTP CRAM-MD5 AUTH : %s\n", buf);
-        free(buf);
-        return 3;
-      }
-
-      memset(buffer, 0, sizeof(buffer));
-      from64tobits((char *) buffer, buf + 4);
-      free(buf);
-
-      memset(buffer2, 0, sizeof(buffer2));
-      sasl_cram_md5(buffer2, pass, buffer);
-
-      sprintf(buffer, "%s %.250s", preplogin, buffer2);
-      hydra_tobase64((unsigned char *) buffer, strlen(buffer), sizeof(buffer));
-
-      char tmp_buffer[sizeof(buffer)];
-      sprintf(tmp_buffer, "%.250s\r\n", buffer);
-      strcpy(buffer, tmp_buffer);
-      free(preplogin);
+    rc = sasl_saslprep(login, SASL_ALLOW_UNASSIGNED, &preplogin);
+    if (rc) {
+      return 3;
     }
-    break;
 
-  case AUTH_DIGESTMD5:{
-      sprintf(buffer, "AUTHINFO SASL DIGEST-MD5\r\n");
-
-      if (hydra_send(s, buffer, strlen(buffer), 0) < 0)
-        return 1;
-      //receive
-      if ((buf = hydra_receive_line(s)) == NULL)
-        return 1;
-      if (buf == NULL || strstr(buf, "383") == NULL || strlen(buf) < 8) {
-        hydra_report(stderr, "[ERROR] NNTP DIGEST-MD5 AUTH : %s\n", buf);
-        free(buf);
-        return 3;
-      }
-      memset(buffer, 0, sizeof(buffer));
-      from64tobits((char *) buffer, buf + 4);
-      free(buf);
-
-      if (debug)
-        hydra_report(stderr, "DEBUG S: %s\n", buffer);
-      fooptr = buffer2;
-      sasl_digest_md5(fooptr, login, pass, buffer, miscptr, "nntp", NULL, 0, NULL);
-      if (fooptr == NULL)
-        return 3;
-
-      if (debug)
-        hydra_report(stderr, "DEBUG C: %s\n", buffer2);
-      hydra_tobase64((unsigned char *) buffer2, strlen(buffer2), sizeof(buffer2));
-      sprintf(buffer, "%s\r\n", buffer2);
+    sprintf(buffer, "AUTHINFO SASL CRAM-MD5\r\n");
+    if (hydra_send(s, buffer, strlen(buffer), 0) < 0) {
+      return 1;
     }
-    break;
+    // get the one-time BASE64 encoded challenge
+    if ((buf = hydra_receive_line(s)) == NULL)
+      return 1;
+    if (buf == NULL || strstr(buf, "383") == NULL) {
+      hydra_report(stderr, "[ERROR] NNTP CRAM-MD5 AUTH : %s\n", buf);
+      free(buf);
+      return 3;
+    }
+
+    memset(buffer, 0, sizeof(buffer));
+    from64tobits((char *)buffer, buf + 4);
+    free(buf);
+
+    memset(buffer2, 0, sizeof(buffer2));
+    result = sasl_cram_md5(buffer2, pass, buffer);
+    if (result == NULL)
+      return 3;
+
+    sprintf(buffer, "%s %.250s", preplogin, buffer2);
+    hydra_tobase64((unsigned char *)buffer, strlen(buffer), sizeof(buffer));
+
+    char tmp_buffer[sizeof(buffer)];
+    sprintf(tmp_buffer, "%.250s\r\n", buffer);
+    strcpy(buffer, tmp_buffer);
+    free(preplogin);
+  } break;
+
+  case AUTH_DIGESTMD5: {
+    sprintf(buffer, "AUTHINFO SASL DIGEST-MD5\r\n");
+
+    if (hydra_send(s, buffer, strlen(buffer), 0) < 0)
+      return 1;
+    // receive
+    if ((buf = hydra_receive_line(s)) == NULL)
+      return 1;
+    if (buf == NULL || strstr(buf, "383") == NULL || strlen(buf) < 8) {
+      hydra_report(stderr, "[ERROR] NNTP DIGEST-MD5 AUTH : %s\n", buf);
+      free(buf);
+      return 3;
+    }
+    memset(buffer, 0, sizeof(buffer));
+    from64tobits((char *)buffer, buf + 4);
+    free(buf);
+
+    if (debug)
+      hydra_report(stderr, "DEBUG S: %s\n", buffer);
+    fooptr = buffer2;
+    result = sasl_digest_md5(fooptr, login, pass, buffer, miscptr, "nntp", NULL, 0, NULL);
+    if (result == NULL)
+      return 3;
+
+    if (debug)
+      hydra_report(stderr, "DEBUG C: %s\n", buffer2);
+    hydra_tobase64((unsigned char *)buffer2, strlen(buffer2), sizeof(buffer2));
+    sprintf(buffer, "%s\r\n", buffer2);
+  } break;
 
 #endif
 
-  case AUTH_NTLM:{
-      unsigned char buf1[4096];
-      unsigned char buf2[4096];
+  case AUTH_NTLM: {
+    unsigned char buf1[4096];
+    unsigned char buf2[4096];
 
-      //send auth and receive challenge
-      buildAuthRequest((tSmbNtlmAuthRequest *) buf2, 0, NULL, NULL);
-      to64frombits(buf1, buf2, SmbLength((tSmbNtlmAuthRequest *) buf2));
-      sprintf(buffer, "AUTHINFO SASL NTLM %s\r\n", (char *) buf1);
-      if (hydra_send(s, buffer, strlen(buffer), 0) < 0) {
-        return 1;
-      }
-      if ((buf = hydra_receive_line(s)) == NULL)
-        return 1;
-      if (buf == NULL || strstr(buf, "383") == NULL || strlen(buf) < 8) {
-        hydra_report(stderr, "[ERROR] NNTP NTLM AUTH : %s\n", buf);
-        free(buf);
-        return 3;
-      }
-      //recover challenge
-      from64tobits((char *) buf1, buf + 4);
-      free(buf);
-
-      buildAuthResponse((tSmbNtlmAuthChallenge *) buf1, (tSmbNtlmAuthResponse *) buf2, 0, login, pass, NULL, NULL);
-      to64frombits(buf1, buf2, SmbLength((tSmbNtlmAuthResponse *) buf2));
-      sprintf(buffer, "%s\r\n", (char *) buf1);
+    // send auth and receive challenge
+    buildAuthRequest((tSmbNtlmAuthRequest *)buf2, 0, NULL, NULL);
+    to64frombits(buf1, buf2, SmbLength((tSmbNtlmAuthRequest *)buf2));
+    sprintf(buffer, "AUTHINFO SASL NTLM %s\r\n", (char *)buf1);
+    if (hydra_send(s, buffer, strlen(buffer), 0) < 0) {
+      return 1;
     }
-    break;
-
-  default:{
-      sprintf(buffer, "AUTHINFO USER %.250s\r\n", login);
-
-      if (hydra_send(s, buffer, strlen(buffer), 0) < 0) {
-        return 1;
-      }
-      buf = hydra_receive_line(s);
-      if (buf == NULL)
-        return 1;
-      if (buf[0] != '3') {
-        if (verbose || debug)
-          hydra_report(stderr, "[ERROR] Not an NNTP protocol or service shutdown: %s\n", buf);
-        free(buf);
-        return (3);
-      }
+    if ((buf = hydra_receive_line(s)) == NULL)
+      return 1;
+    if (buf == NULL || strstr(buf, "383") == NULL || strlen(buf) < 8) {
+      hydra_report(stderr, "[ERROR] NNTP NTLM AUTH : %s\n", buf);
       free(buf);
-      sprintf(buffer, "AUTHINFO PASS %.250s\r\n", pass);
+      return 3;
     }
-    break;
+    // recover challenge
+    from64tobits((char *)buf1, buf + 4);
+    free(buf);
+
+    buildAuthResponse((tSmbNtlmAuthChallenge *)buf1, (tSmbNtlmAuthResponse *)buf2, 0, login, pass, NULL, NULL);
+    to64frombits(buf1, buf2, SmbLength((tSmbNtlmAuthResponse *)buf2));
+    sprintf(buffer, "%s\r\n", (char *)buf1);
+  } break;
+
+  default: {
+    sprintf(buffer, "AUTHINFO USER %.250s\r\n", login);
+
+    if (hydra_send(s, buffer, strlen(buffer), 0) < 0) {
+      return 1;
+    }
+    buf = hydra_receive_line(s);
+    if (buf == NULL)
+      return 1;
+    if (buf[0] != '3') {
+      if (verbose || debug)
+        hydra_report(stderr, "[ERROR] Not an NNTP protocol or service shutdown: %s\n", buf);
+      free(buf);
+      return (3);
+    }
+    free(buf);
+    sprintf(buffer, "AUTHINFO PASS %.250s\r\n", pass);
+  } break;
   }
 
-
   if (hydra_send(s, buffer, strlen(buffer), 0) < 0) {
     return 1;
   }
@@ -266,7 +265,7 @@ int32_t start_nntp(int32_t s, char *ip, int32_t port, unsigned char options, cha
   return 2;
 }
 
-void service_nntp(char *ip, int32_t sp, unsigned char options, char *miscptr, FILE * fp, int32_t port, char *hostname) {
+void service_nntp(char *ip, int32_t sp, unsigned char options, char *miscptr, FILE *fp, int32_t port, char *hostname) {
   int32_t i = 0, run = 1, next_run = 1, sock = -1;
   int32_t myport = PORT_NNTP, mysslport = PORT_NNTP_SSL, disable_tls = 0;
   char *buffer1 = "CAPABILITIES\r\n";
@@ -276,10 +275,10 @@ void service_nntp(char *ip, int32_t sp, unsigned char options, char *miscptr, FI
     return;
   while (1) {
     switch (run) {
-    case 1:                    /* connect and service init function */
+    case 1: /* connect and service init function */
       if (sock >= 0)
         sock = hydra_disconnect(sock);
-//      usleepn(300);
+      //      usleepn(300);
       if ((options & OPTION_SSL) == 0) {
         if (port != 0)
           myport = port;
@@ -293,12 +292,12 @@ void service_nntp(char *ip, int32_t sp, unsigned char options, char *miscptr, FI
       }
       if (sock < 0) {
         if (verbose || debug)
-          hydra_report(stderr, "[ERROR] Child with pid %d terminating, can not connect\n", (int32_t) getpid());
+          hydra_report(stderr, "[ERROR] Child with pid %d terminating, can not connect\n", (int32_t)getpid());
         hydra_child_exit(1);
       }
-//      usleepn(300);
+      //      usleepn(300);
       buf = hydra_receive_line(sock);
-      if (buf == NULL || buf[0] != '2') {       /* check the first line */
+      if (buf == NULL || buf[0] != '2') { /* check the first line */
         if (verbose || debug)
           hydra_report(stderr, "[ERROR] Not an NNTP protocol or service shutdown: %s\n", buf);
         hydra_child_exit(2);
@@ -352,10 +351,10 @@ void service_nntp(char *ip, int32_t sp, unsigned char options, char *miscptr, FI
       }
 #endif
 
-/*  
-AUTHINFO USER SASL
-SASL PLAIN DIGEST-MD5 LOGIN NTLM CRAM-MD5
-*/
+      /*
+      AUTHINFO USER SASL
+      SASL PLAIN DIGEST-MD5 LOGIN NTLM CRAM-MD5
+      */
 
 #ifdef HAVE_PCRE
       if (hydra_string_match(buf, "SASL\\s.*NTLM")) {
@@ -405,7 +404,7 @@ SASL PLAIN DIGEST-MD5 LOGIN NTLM CRAM-MD5
 
       if ((miscptr != NULL) && (strlen(miscptr) > 0)) {
         for (i = 0; i < strlen(miscptr); i++)
-          miscptr[i] = (char) toupper((int32_t) miscptr[i]);
+          miscptr[i] = (char)toupper((int32_t)miscptr[i]);
 
         if (strncmp(miscptr, "USER", 4) == 0)
           nntp_auth_mechanism = AUTH_CLEAR;
@@ -426,7 +425,6 @@ SASL PLAIN DIGEST-MD5 LOGIN NTLM CRAM-MD5
 
         if (strncmp(miscptr, "NTLM", 4) == 0)
           nntp_auth_mechanism = AUTH_NTLM;
-
       }
       if (verbose) {
         switch (nntp_auth_mechanism) {
@@ -456,10 +454,10 @@ SASL PLAIN DIGEST-MD5 LOGIN NTLM CRAM-MD5
       free(buf);
       next_run = 2;
       break;
-    case 2:                    /* run the cracking function */
+    case 2: /* run the cracking function */
       next_run = start_nntp(sock, ip, port, options, miscptr, fp);
       break;
-    case 3:                    /* clean exit */
+    case 3: /* clean exit */
       if (sock >= 0)
         sock = hydra_disconnect(sock);
       hydra_child_exit(0);
@@ -472,13 +470,13 @@ SASL PLAIN DIGEST-MD5 LOGIN NTLM CRAM-MD5
   }
 }
 
-int32_t service_nntp_init(char *ip, int32_t sp, unsigned char options, char *miscptr, FILE * fp, int32_t port, char *hostname) {
+int32_t service_nntp_init(char *ip, int32_t sp, unsigned char options, char *miscptr, FILE *fp, int32_t port, char *hostname) {
   // called before the childrens are forked off, so this is the function
   // which should be filled if initial connections and service setup has to be
   // performed once only.
   //
   // fill if needed.
-  // 
+  //
   // return codes:
   //   0 all OK
   //   -1  error, hydra will exit, so print a good error message here
@@ -486,6 +484,7 @@ int32_t service_nntp_init(char *ip, int32_t sp, unsigned char options, char *mis
   return 0;
 }
 
-void usage_nntp(const char* service) {
-  printf("Module nntp is optionally taking one authentication type of:\n" "  USER (default), LOGIN, PLAIN, CRAM-MD5, DIGEST-MD5, NTLM\n\n");
+void usage_nntp(const char *service) {
+  printf("Module nntp is optionally taking one authentication type of:\n"
+         "  USER (default), LOGIN, PLAIN, CRAM-MD5, DIGEST-MD5, NTLM\n\n");
 }
